[][src]Struct amitu_base::point::Point

pub struct Point {
    pub lat: f64,
    pub long: f64,
}

Point is represented in Postgres as a tuple of 64 bit floating point values (x, y). This struct is a dumb wrapper type, meant only to indicate the tuple's meaning.

Fields

lat: f64long: f64