[−][src]Struct amitu_base::point::Point
Point is represented in Postgres as a tuple of 64 bit floating point values (x, y). This struct is a dumb wrapper type, meant only to indicate the tuple's meaning.
Fields
lat: f64long: f64Trait Implementations
impl Clone for Point[src]
impl PartialEq<Point> for Point[src]
impl Copy for Point[src]
impl Debug for Point[src]
impl<'expr> AsExpression<PgPoint> for &'expr Point[src]
type Expression = Bound<PgPoint, Self>
The expression being returned
fn as_expression(self) -> Self::Expression[src]
impl<'expr> AsExpression<Nullable<PgPoint>> for &'expr Point[src]
type Expression = Bound<Nullable<PgPoint>, Self>
The expression being returned
fn as_expression(self) -> Self::Expression[src]
impl AsExpression<PgPoint> for Point[src]
type Expression = Bound<PgPoint, Self>
The expression being returned
fn as_expression(self) -> Self::Expression[src]
impl AsExpression<Nullable<PgPoint>> for Point[src]
type Expression = Bound<Nullable<PgPoint>, Self>
The expression being returned
fn as_expression(self) -> Self::Expression[src]
impl<__ST, __DB> Queryable<__ST, __DB> for Point where
__DB: Backend,
Self: FromSql<__ST, __DB>, [src]
__DB: Backend,
Self: FromSql<__ST, __DB>,
type Row = Self
The Rust type you'd like to map from. Read more
fn build(row: Self::Row) -> Self[src]
impl NotNull for Point[src]
impl SingleValue for Point[src]
impl<__DB> ToSql<Nullable<PgPoint>, __DB> for Point where
__DB: Backend,
Self: ToSql<PgPoint, __DB>, [src]
__DB: Backend,
Self: ToSql<PgPoint, __DB>,
impl ToSql<PgPoint, Pg> for Point[src]
impl FromSql<PgPoint, Pg> for Point[src]
impl<__ST, __DB> FromSqlRow<__ST, __DB> for Point where
__DB: Backend,
Self: FromSql<__ST, __DB>, [src]
__DB: Backend,
Self: FromSql<__ST, __DB>,
fn build_from_row<R: Row<__DB>>(row: &mut R) -> Result<Self>[src]
const FIELDS_NEEDED: usize[src]
impl Serialize for Point[src]
fn serialize<__S>(&self, __serializer: __S) -> Result<__S::Ok, __S::Error> where
__S: Serializer, [src]
__S: Serializer,
impl<'de> Deserialize<'de> for Point[src]
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>, [src]
__D: Deserializer<'de>,